import onnx
import ktc
from PIL import Image
import numpy as np
import os

# image_size = 512
img_width = 256
img_heigh = 192

def preprocess(input_file):
    image = Image.open(input_file)
    image = image.convert("RGB")
    img_data = np.array(image.resize((img_heigh, img_width), Image.BILINEAR)) / 256 - 0.5
    img_data = np.transpose(img_data, (2, 0, 1))
    img_data = np.expand_dims(img_data, 0)
    return img_data

original_m = onnx.load("end2end.onnx")
# Optimize the model using optimizer for onnx model.
result_m = ktc.onnx_optimizer.torch_exported_onnx_flow(original_m)
optimized_m = ktc.onnx_optimizer.onnx2onnx_flow(result_m)
# Save the onnx object optimized_m to path /data1/optimized.onnx.
onnx.save(optimized_m, '/data1/optimized.onnx')

km = ktc.ModelConfig(1, "0001", "720", onnx_model=optimized_m)

# Evaluate the model. The evaluation result is saved as string into `eval_result`.
eval_result = km.evaluate(output_dir="/data1/kneron_flow")
print("\nNpu performance evaluation result:\n" + str(eval_result))

raw_images = os.listdir("/workspace/test_files/")
input_images = [preprocess("/workspace/test_files/" + image_name) for image_name in raw_images]

input_mapping = {"input": input_images}
# bie_model_path = km.analysis(input_mapping, threads = 8, fm_cut="deep_search")
# bie_model_path = km.analysis(input_mapping)
bie_model_path = km.analysis(input_mapping, output_dir="/data1/kneron_flow")
print("\nFixed-point analysis done. Save bie model to '" + str(bie_model_path) + "'")


nef_model_path = ktc.compile([km])
print("\nCompile done. Save Nef file to '" + str(nef_model_path) + "'")